@@ -1,4 +1,4 @@
-#### $Id: misc-goodies.R,v 1.31 2005/04/25 10:06:57 maechler Exp $
+#### $Id: misc-goodies.R,v 1.32 2006/03/09 07:27:10 maechler Exp $
 #### misc-goodies.R
 #### ~~~~~~~~~~~~~~  SfS - R - goodies that are NOT in
 ####		"/u/sfs/R/SfS/R/u.goodies.R"
@@ -181,6 +181,65 @@ plotStep <- function(ti, y,
   invisible(list(t = ti, y = y))
 }
 
+hist.bxp <-
+    function(x, nclass, breaks, probability = FALSE, include.lowest = TRUE,
+             xlab = deparse(substitute(x)), ..., width = 0.2,
+             boxcol = 3, medcol = 2, medlwd = 5, whisklty = 2, staplelty = 1)
+{
+  ## Purpose:   Plot a histogram and a boxplot
+  ## -------------------------------------------------------------------------
+  ## Arguments: ---> see help(hist.bxp) !
+  ## -------------------------------------------------------------------------
+  ## Authors: Christian Keller, Date: 10 Nov 95,  (Martin Maechler, Jan 96)
+  ##						calls  p.hboxp(.) !
+
+  ## determine the height of the plot
+  if(missing(breaks)){
+    if(missing(nclass))
+      h <- hist(x, probability = probability, include.lowest = include.lowest,
+		plot = FALSE)
+      else
+	h <- hist(x, nclass = nclass, probability = probability,
+		  include.lowest = include.lowest, plot = FALSE)
+  }
+    else
+      h <- hist(x, breaks = breaks, probability = probability,
+		include.lowest = include.lowest, plot = FALSE)
+  ymax <- max(h$counts)
+  ymin <-  - ymax * width # range:  (-w,1)*ymax  instead of  (0,1)*ymax
+
+  ##------- drawing the histogram -------------
+  hist(x, breaks = h$breaks, probability = probability,
+       include.lowest = include.lowest, plot = TRUE, xlab = xlab,
+       ylim = c(ymin, ymax), axes = FALSE, ...)
+  axis(1)
+  axis(2, at = pretty(c(0,ymax), n = 5), srt = 90) ## ph, 8.5.00: n instead of nint
+  abline(h = 0)				#
+  ##-------- drawing the boxplot --------------
+
+  ##-- scale a range
+  scale.r <- function(x1,x2, fact = 1.1)
+    (x1+x2)/2 + c(-fact,fact) * (x2-x1)/2
+
+  ##-- since 4% extra space above x-axis (just below ymin):
+  ##-   cat("par$usr[3:4]:", par("usr")[3:4],
+  ##- 	    "  ymin -.04 *(ymax-ymin)",ymin -.04 *(ymax-ymin),"\n")
+  ##-- NOTE: Always have (seemingly): par("usr")[3] == ymin -.04 *(ymax-ymin)
+
+##-O- ORIGINAL VERSION (Keller & Keller) :
+##-O-   p.hboxp(x, ymin, -.04 *(ymax-ymin),
+##-O- 	  boxcol=boxcol, medcol=medcol,
+##-O- 	  medlwd=medlwd, whisklty=whisklty, staplelty=staplelty)
+
+  ##---- This is  much better for width <=.1 or so...
+  ##-- but you should leave some white space -> scale down
+  ##-- The scaling factor is really a  KLUDGE but works for a wide range!
+  p.hboxp(x, scale.r(par("usr")[3], 0, ## ph, 8.5.00: changed f=.9 to f=.8
+		     f = .8 - max(0, .15 - width)*(1+(par("mfg")[3] >= 3))),
+	  boxcol = boxcol, medcol = medcol,
+	  medlwd = medlwd, whisklty = whisklty, staplelty = staplelty)
+}
+
 
 
 ##-#### Print & Strings  ########
@@ -380,69 +439,12 @@ uniqueL <- function(x, isuniq = !duplicated(x)) {
     list(ix = ix, xU = x[isuniq])
 }
 
+
 ###
 ### autoreg(),  mean.cor()  etc ... not yet
 ###
 ### if  we take them, use different file !!
 
-hist.bxp <- function(x, nclass, breaks, probability = FALSE, include.lowest = TRUE,
-		     xlab = deparse(substitute(x)), ..., width = 0.2,
-		     boxcol = 3, medcol = 2, medlwd = 5, whisklty = 2, staplelty = 1)
-{
-  ## Purpose:   Plot a histogram and a boxplot
-  ## -------------------------------------------------------------------------
-  ## Arguments: ---> see help(hist.bxp) !
-  ## -------------------------------------------------------------------------
-  ## Authors: Christian Keller, Date: 10 Nov 95,  (Martin Maechler, Jan 96)
-  ##						calls  p.hboxp(.) !
-
-  ## determine the height of the plot
-  if(missing(breaks)){
-    if(missing(nclass))
-      h <- hist(x, probability = probability, include.lowest = include.lowest,
-		plot = FALSE)
-      else
-	h <- hist(x, nclass = nclass, probability = probability,
-		  include.lowest = include.lowest, plot = FALSE)
-  }
-    else
-      h <- hist(x, breaks = breaks, probability = probability,
-		include.lowest = include.lowest, plot = FALSE)
-  ymax <- max(h$counts)
-  ymin <-  - ymax * width # range:  (-w,1)*ymax  instead of  (0,1)*ymax
-
-  ##------- drawing the histogram -------------
-  hist(x, breaks = h$breaks, probability = probability,
-       include.lowest = include.lowest, plot = TRUE, xlab = xlab,
-       ylim = c(ymin, ymax), axes = FALSE, ...)
-  axis(1)
-  axis(2, at = pretty(c(0,ymax), n = 5), srt = 90) ## ph, 8.5.00: n instead of nint
-  abline(h = 0)				#
-  ##-------- drawing the boxplot --------------
-
-  ##-- scale a range
-  scale.r <- function(x1,x2, fact = 1.1)
-    (x1+x2)/2 + c(-fact,fact) * (x2-x1)/2
-
-  ##-- since 4% extra space above x-axis (just below ymin):
-  ##-   cat("par$usr[3:4]:", par("usr")[3:4],
-  ##- 	    "  ymin -.04 *(ymax-ymin)",ymin -.04 *(ymax-ymin),"\n")
-  ##-- NOTE: Always have (seemingly): par("usr")[3] == ymin -.04 *(ymax-ymin)
-
-##-O- ORIGINAL VERSION (Keller & Keller) :
-##-O-   p.hboxp(x, ymin, -.04 *(ymax-ymin),
-##-O- 	  boxcol=boxcol, medcol=medcol,
-##-O- 	  medlwd=medlwd, whisklty=whisklty, staplelty=staplelty)
-
-  ##---- This is  much better for width <=.1 or so...
-  ##-- but you should leave some white space -> scale down
-  ##-- The scaling factor is really a  KLUDGE but works for a wide range!
-  p.hboxp(x, scale.r(par("usr")[3], 0, ## ph, 8.5.00: changed f=.9 to f=.8
-		     f = .8 - max(0, .15 - width)*(1+(par("mfg")[3] >= 3))),
-	  boxcol = boxcol, medcol = medcol,
-	  medlwd = medlwd, whisklty = whisklty, staplelty = staplelty)
-}
-
 
 
 ####========== This is from /u/maechler/S/Good.S =============
